@@ -13,6 +13,10 @@ double hs_BRep_Tool_curveParamFirst(TopoDS_Edge * edge);
 
 double hs_BRep_Tool_curveParamLast(TopoDS_Edge * edge);
 
+gp_Pnt * hs_BRep_Tool_pnt(TopoDS_Vertex * vertex);
+
+Handle(Poly_Triangulation) * hs_BRep_Tool_triangulation(TopoDS_Face * face, TopLoc_Location * loc);
+
 #ifdef __cplusplus
 }
 #endif
