@@ -1,6 +1,7 @@
 {-# LANGUAGE CApiFFI #-}
 module OpenCascade.BRepFilletAPI.Internal.Destructors
 ( deleteMakeFillet
+, deleteMakeChamfer
 ) where
 
 import OpenCascade.BRepFilletAPI.Types
@@ -9,4 +10,6 @@ import Foreign.Ptr
 
 foreign import capi unsafe "hs_BRepFilletAPI_MakeFillet.h hs_delete_BRepFilletAPI_MakeFillet" deleteMakeFillet :: Ptr MakeFillet -> IO ()
 
+foreign import capi unsafe "hs_BRepFilletAPI_MakeChamfer.h hs_delete_BRepFilletAPI_MakeChamfer" deleteMakeChamfer :: Ptr MakeChamfer -> IO ()
+
 
