@@ -2,6 +2,8 @@
 {-# LANGUAGE EmptyDataDecls #-}
 module OpenCascade.StlAPI.Types 
 ( Writer
+, Reader
 ) where
 
-data Writer
\ No newline at end of file
+data Writer
+data Reader
\ No newline at end of file
